==> unity-changeset-2.0.1.tgz: package/esm/index.js <==
import "./_dnt.polyfills.js";
import * as dntShim from "./_dnt.shims.js";
import { UnityChangeset } from "./unityChangeset.js";
import { distinctBy, sortBy, } from "./deps/deno.land/std@0.180.0/collections/mod.js";
const REGEXP_HUB_LINKS = /unityhub:\/\/\d{4}\.\d+\.\d+(a|b|f)\d+\/\w{12}/g;
const UNITY_ARCHIVE_URL = "https://unity3d.com/get-unity/download/archive";
const UNITY_ALPHA_URL = "https://unity3d.com/unity/alpha/";
const UNITY_BETA_URL = "https://unity3d.com/unity/beta/";
const UNITY_RSS_URL = "https://unity.com/releases/editor/releases.xml";
const UNITY_BETA_RSS_URL = "https://unity3d.com/unity/beta/latest.xml";
/*
 * Get an Unity changeset from specific Unity version.
 * @param version The Unity version.
 * @returns An Unity changeset.
 */
export async function getUnityChangeset(version) {
    const match = version.match(/^\d{4}\.\d+\.\d+(a|b|f)\d+$/);
    const lifecycle = match?.[1];
    switch (lifecycle) {
        case "f":
            return (await scrapeArchivedChangesets())
                .filter((c) => c.version === version)[0];
        case "a":
            return (await getUnityChangesetsFromUrl(UNITY_ALPHA_URL + version))
                .filter((c) => c.version === version)[0];
        case "b":
            return (await getUnityChangesetsFromUrl(UNITY_BETA_URL + version))
                .filter((c) => c.version === version)[0];
        default:
            throw Error(`The given life-cycle '${lifecycle}' (in ${version}) was not supported`);
    }
}
/*
 * Scrape the archived Unity changesets from Unity archives.
 * @returns The Unity changesets.
 */
export async function scrapeArchivedChangesets() {
    const changesets = (await getUnityChangesetsFromUrl(UNITY_ARCHIVE_URL))
        .concat(await getUnityChangesetsFromUrl(UNITY_RSS_URL));
    return sortBy(distinctBy(changesets, (c) => c.versionNumber), (c) => -c.versionNumber);
}
/*
 * Scrape the alpha/beta Unity changesets from Unity RSS feed.
 * @returns The Unity changesets (alpha/beta).
 */
export function scrapeBetaChangesets() {
    return getUnityChangesetsFromUrl(UNITY_BETA_RSS_URL);
}
async function getUnityChangesetsFromUrl(url) {
    const response = await dntShim.fetch(url);
    const raw = await response.text();
    const match = raw.match(REGEXP_HUB_LINKS);
    if (!match) {
        throw new Error(`No changesets found at '${url}'`);
    }
    return match.map((m) => UnityChangeset.createFromHref(m));
}

==> unity-changeset-2.0.2.tgz: package/esm/index.js <==
import * as dntShim from "./_dnt.shims.js";
import { UnityChangeset } from "./unityChangeset.js";
const REGEXP_HUB_LINKS = /unityhub:\/\/\d{4}\.\d+\.\d+(a|b|f)\d+\/\w{12}/g;
const UNITY_ARCHIVE_URL = "https://unity3d.com/get-unity/download/archive";
const UNITY_ALPHA_URL = "https://unity3d.com/unity/alpha/";
const UNITY_BETA_URL = "https://unity3d.com/unity/beta/";
const UNITY_RSS_URL = "https://unity.com/releases/editor/releases.xml";
const UNITY_BETA_RSS_URL = "https://unity3d.com/unity/beta/latest.xml";
/*
 * Get an Unity changeset from specific Unity version.
 * @param version The Unity version.
 * @returns An Unity changeset.
 */
export async function getUnityChangeset(version) {
    const match = version.match(/^\d{4}\.\d+\.\d+(a|b|f)\d+$/);
    const lifecycle = match?.[1];
    switch (lifecycle) {
        case "f":
            return (await scrapeArchivedChangesets())
                .filter((c) => c.version === version)[0];
        case "a":
            return (await getUnityChangesetsFromUrl(UNITY_ALPHA_URL + version))
                .filter((c) => c.version === version)[0];
        case "b":
            return (await getUnityChangesetsFromUrl(UNITY_BETA_URL + version))
                .filter((c) => c.version === version)[0];
        default:
            throw Error(`The given life-cycle '${lifecycle}' (in ${version}) was not supported`);
    }
}
/*
 * Scrape the archived Unity changesets from Unity archives.
 * @returns The Unity changesets.
 */
export async function scrapeArchivedChangesets() {
    const changesets = (await getUnityChangesetsFromUrl(UNITY_ARCHIVE_URL))
        .concat(await getUnityChangesetsFromUrl(UNITY_RSS_URL));
    const unique = new Set();
    return changesets.filter((c) => {
        const duplicated = unique.has(c.versionNumber);
        unique.add(c.versionNumber);
        return !duplicated;
    })
        .sort((a, b) => b.versionNumber - a.versionNumber);
}
/*
 * Scrape the alpha/beta Unity changesets from Unity RSS feed.
 * @returns The Unity changesets (alpha/beta).
 */
export function scrapeBetaChangesets() {
    return getUnityChangesetsFromUrl(UNITY_BETA_RSS_URL);
}
async function getUnityChangesetsFromUrl(url) {
    const response = await dntShim.fetch(url);
    const raw = await response.text();
    const match = raw.match(REGEXP_HUB_LINKS);
    if (!match) {
        throw new Error(`No changesets found at '${url}'`);
    }
    return match.map((m) => UnityChangeset.createFromHref(m));
}
